@@ -1,17 +1,17 @@
-# $Id: interwiki.rb,v 1.10 2005/12/28 23:42:18 fdiary Exp $
+# $Id: interwiki.rb,v 1.10 2005-12-28 23:42:18 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 module Hiki
   class InterWiki
     require 'hiki/util'
-    
+
     URL  = '(?:http|https|ftp|mailto|file):[a-zA-Z0-9;/?:@&=+$,\-_.!~*\'()#%]+'
     INTERWIKI_NAME_RE =  /\[\[([^|]+)\|(#{URL})\]\](?:\s+(sjis|euc|utf8|alias))?/
 
     attr_reader :interwiki_names
-    
+
     def initialize( str )
-      @interwiki_names = Hash::new
+      @interwiki_names = Hash.new
       (str || '').scan( INTERWIKI_NAME_RE ) do |i|
         e = i.size > 2 ? i[2] : 'none'
         @interwiki_names[i[0]] = {:url => i[1], :encoding => e}
@@ -43,9 +43,9 @@ module Hiki
 
     def outer_alias(s)
       if @interwiki_names.has_key?(s) && @interwiki_names[s][:encoding] == 'alias'
-	return [@interwiki_names[s][:url].escapeHTML, s.escapeHTML]
+        return [@interwiki_names[s][:url].escapeHTML, s.escapeHTML]
       else
-	return nil
+        return nil
       end
     end
   end
