@@ -1,4 +1,4 @@
-# $Id: plugin.rb,v 1.36 2006/09/02 06:36:57 znz Exp $
+# $Id: plugin.rb,v 1.37 2008-02-12 15:06:08 hiraku Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # Copyright (C) 2004-2005 Kazuhiko <kazuhiko@fdiary.net>
 #
@@ -6,17 +6,19 @@
 
 require 'cgi'
 require 'uri'
+require 'erb'
 require 'hiki/util'
 
 module Hiki
   class PluginError < StandardError; end
 
   class Plugin
+    include ERB::Util
     attr_reader   :toc_f, :plugin_command
     attr_accessor :text, :title, :cookies, :user, :data, :session_id
 
     TOC_STRING = "\000\000[Table of Contents]"
-    
+
     def initialize( options, conf )
       @options      = options
       @conf         = conf
@@ -38,10 +40,10 @@ module Hiki
       @conf_procs       = {}
       @mode             = ''
 
-      options.each_key do |opt|
-        eval("@#{opt} = options['#{opt}']") unless opt.index('.')
+      options.each do |opt, val|
+        instance_variable_set("@#{opt}", val) unless opt.index('.')
       end
-      
+
       @toc_f            = false
       @context          = nil
       @plugin_command   = []
@@ -120,7 +122,7 @@ module Hiki
         end
       end
     end
-    
+
     def body_enter_proc
       r = []
       @body_enter_procs.each do |proc|
@@ -180,7 +182,7 @@ module Hiki
       end
       r.join
     end
-      
+
     def form_proc
       r = []
       @form_procs.each do |proc|
@@ -192,7 +194,7 @@ module Hiki
       end
       r.join
     end
-    
+
     def menu_proc
       r = []
       @menu_procs.each do |proc|
@@ -204,7 +206,7 @@ module Hiki
       end
       r.compact
     end
-    
+
     def add_cookie( cookie )
       @cookies << cookie
     end
@@ -279,7 +281,9 @@ module Hiki
       @db.load_backup( page )
     end
 
-    def save( page, src, md5, update_timestamp = true )
+    def save( page, src, md5, update_timestamp = true, filtering = true )
+      return false if filtering and Filter.new_page_is_spam?(page, src)
+
       src.gsub!(/\r/, '')
       src.sub!(/\A\n*/, '')
       src.sub!(/\n*\z/, "\n")
@@ -390,8 +394,8 @@ module Hiki
     def set_tdiary_env
       @date             = Time::now
       @cookies          = []
-      
-      @options['cache_path']  = @conf.cache_path 
+
+      @options['cache_path']  = @conf.cache_path
       @options['mode']        = "day"
 #      @options['author_name'] = @conf.author_name || 'anonymous'
 #      @options['author_mail'] = @conf.mail
@@ -400,9 +404,9 @@ module Hiki
       @options['years']       = {}
       @options['diaries']     = nil,
       @options['date']        = Time::now
- 
+
       %w(cache_path mode years diaries date).each do |p|
-        eval("@#{p} = @options['#{p}']")
+        instance_variable_set("@#{p}", @options[p])
       end
     end
   end
