@@ -1,4 +1,4 @@
-# $Id: util.rb,v 1.44 2005/12/25 07:03:06 yanagita Exp $
+# $Id: util.rb,v 1.44 2005-12-25 07:03:06 yanagita Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'nkf'
@@ -8,32 +8,35 @@ autoload( :Document, 'docdiff' )
 autoload( :Diff, 'docdiff' )
 
 class String
+  # all instance methods added in String class will be obsoleted in the
+  # future release.
+
   def to_euc
-    NKF::nkf('-m0 -e', self)
+    NKF.nkf('-m0 -e', self)
   end
 
   def to_sjis
-    NKF::nkf('-m0 -s', self)
+    NKF.nkf('-m0 -s', self)
   end
 
   def to_jis
-    NKF::nkf('-m0 -j', self)
+    NKF.nkf('-m0 -j', self)
   end
-  
+
   def escape
-    CGI::escape(self)
+    CGI.escape(self)
   end
 
   def unescape
-    CGI::unescape(self)
+    CGI.unescape(self)
   end
 
   def escapeHTML
-    CGI::escapeHTML(self)
+    CGI.escapeHTML(self)
   end
 
   def unescapeHTML
-    CGI::unescapeHTML(self)
+    CGI.unescapeHTML(self)
   end
 
   def sanitize
@@ -60,7 +63,7 @@ module Hiki
     end
 
     def title( s )
-      CGI::escapeHTML( "#{@conf.site_name} - #{s}" )
+      CGI.escapeHTML( "#{@conf.site_name} - #{s}" )
     end
 
     def view_title( s )
@@ -72,9 +75,9 @@ module Hiki
     end
 
     def get_common_data( db, plugin, conf )
-      data = Hash::new
+      data = Hash.new
       data[:author_name] = conf.author_name
-      data[:view_style]  = conf.use_sidebar ? CGI::escapeHTML( conf.main_class ) : 'hiki' # for tDiary theme
+      data[:view_style]  = conf.use_sidebar ? CGI.escapeHTML( conf.main_class ) : 'hiki' # for tDiary theme
       data[:cgi_name]    = conf.cgi_name
       if conf.use_sidebar
         t = db.load_cache( conf.side_menu )
@@ -87,7 +90,7 @@ module Hiki
         f = conf.formatter.new( t, db, plugin, conf, 's' )
         data[:sidebar]   = f.to_s
         data[:main_class]    = conf.main_class
-        data[:sidebar_class] = CGI::escapeHTML( conf.sidebar_class )
+        data[:sidebar_class] = CGI.escapeHTML( conf.sidebar_class )
       else
         data[:sidebar] = nil
       end
@@ -161,12 +164,12 @@ module Hiki
           smtp.send_mail <<EndOfMail, from_addr, *to_addrs
 From: #{from_addr}
 To: #{to_addrs.join(",")}
-Subject: #{NKF::nkf('-M', subject)}
+Subject: #{NKF.nkf('-M', subject)}
 Date: #{Time.now.rfc2822}
 MIME-Version: 1.0
 Content-Type: text/plain; charset="iso-2022-jp"
 Content-Transfer-Encoding: 7bit
-X-Mailer: Hiki #{HIKI_VERSION}
+X-Mailer: Hiki #{Hiki::VERSION}
 
 #{body.to_jis}
 EndOfMail
@@ -219,8 +222,8 @@ EOS
     end
 
     def euc_to_utf8(str)
-      if NKF::const_defined?(:UTF8)
-        return NKF::nkf('-m0 -w', str)
+      if NKF.const_defined?(:UTF8)
+        return NKF.nkf('-m0 -w', str)
       else
         begin
           require 'uconv'
@@ -230,10 +233,10 @@ EOS
         return Uconv.euctou8(str)
       end
     end
-  
+
     def utf8_to_euc(str)
-      if NKF::const_defined?(:UTF8)
-        return NKF::nkf('-m0 -e', str)
+      if NKF.const_defined?(:UTF8)
+        return NKF.nkf('-m0 -e', str)
       else
         begin
           require 'uconv'
@@ -244,6 +247,35 @@ EOS
       end
     end
 
+    def to_native(str, charset=nil)
+      # XXX to_charset will be 'utf-8' in the future version
+      begin
+        Iconv.conv(@charset, charset || 'utf-8', str)
+      rescue
+        from = case charset
+               when /^utf-8$/i
+                 'W'
+               when /^shift_jis/i
+                 'S'
+               when /^EUC-JP/i
+                 'E'
+               else
+                 ''
+               end
+        to = case @charset
+               when /^utf-8$/i
+                 'w'
+               when /^shift_jis/i
+                 's'
+               when /^EUC-JP/i
+                 'e'
+               else
+                 'e' # XXX what should we use?
+               end
+        NKF::nkf("-m0 -#{from}#{to}", str)
+      end
+    end
+
     def compare_by_line(doc1, doc2)
       Difference.new(doc1.split_to_line, doc2.split_to_line)
     end
