@@ -1,4 +1,4 @@
-# $Id: xmlrpc.rb,v 1.8 2007/03/14 08:49:00 znz Exp $
+# $Id: xmlrpc.rb,v 1.9 2007-09-25 06:23:41 fdiary Exp $
 
 require 'xmlrpc/server'
 require 'hiki/plugin'
@@ -10,8 +10,8 @@ module Hiki
     def init_handler(server, cgi_class=CGI)
       server.add_handler('wiki.getPage') do |page|
         page = utf8_to_euc( page )
-        conf = Hiki::Config::new
-        db = Hiki::HikiDB::new( conf )
+        conf = Hiki::Config.new
+        db = conf.database
         ret = db.load( page )
         unless ret
           raise XMLRPC::FaultException.new(1, "No such page was found.")
@@ -21,8 +21,8 @@ module Hiki
 
       server.add_handler('wiki.getPageInfo') do |page|
         page = utf8_to_euc( page )
-        conf = Hiki::Config::new
-        db = Hiki::HikiDB::new( conf )
+        conf = Hiki::Config.new
+        db = conf.database
         title = db.get_attribute( page, :title )
         title = page if title.nil? || title.empty?
         {
@@ -46,18 +46,19 @@ module Hiki
             v.map!{ |s| s.replace( utf8_to_euc( s ) ) }
           end
         }
-        conf = Hiki::Config::new
-        cgi = cgi_class::new
+        conf = Hiki::Config.new
+        cgi = cgi_class.new
         cgi.params['c'] = ['save']
         cgi.params['p'] = [page]
-        db = Hiki::HikiDB::new( conf )
-        options = conf.options || Hash::new( '' )
+        db = conf.database
+        options = conf.options || Hash.new( '' )
         options['page'] = page
         options['cgi']  = cgi
         options['db']  = db
-        options['params'] = Hash::new( [] )
-        plugin = Hiki::Plugin::new( options, conf )
+        options['params'] = Hash.new( [] )
+        plugin = Hiki::Plugin.new( options, conf )
         plugin.login( attributes['name'], attributes['password'] )
+        Hiki::Filter.init(conf, cgi, plugin, db)
 
         unless plugin.editable?( page )
           raise XMLRPC::FaultException.new(10, "can't edit this page.")
@@ -80,8 +81,8 @@ module Hiki
       end
 
       server.add_handler('wiki.getAllPages') do
-        conf = Hiki::Config::new
-        db = Hiki::HikiDB::new( conf )
+        conf = Hiki::Config.new
+        db = conf.database
         db.pages.collect{|p| XMLRPC::Base64.new( euc_to_utf8( p ) )}
       end
 
