@@ -1,9 +1,10 @@
+# -*- coding: euc-jp -*-
 =begin
 
 == plugin/history.rb - CVS Խɽץ饰
 
   Copyright (C) 2003 Hajime BABA <baba.hajime@nifty.com>
-  $Id: history.rb,v 1.28 2005/06/29 06:10:45 fdiary Exp $
+  $Id: history.rb,v 1.29 2007-09-24 21:23:09 fdiary Exp $
   You can redistribute and/or modify this file under the terms of the LGPL.
 
   Copyright (C) 2003 Yasuo Itabashi <yasuo_itabashi{@}hotmail.com>
@@ -53,21 +54,21 @@ CSSspan.add_line, span.del_lineꤹȡѹսʸ°ѹǤޤ
 =end
 
 def history
-  h = Hiki::History::new(@cgi, @db, @conf)
+  h = Hiki::History.new(@cgi, @db, @conf)
   h.history
 end
 
 def history_src
-  h = Hiki::History::new(@cgi, @db, @conf)
+  h = Hiki::History.new(@cgi, @db, @conf)
   h.history_src
 end
 
 def history_diff
-  h = Hiki::History::new(@cgi, @db, @conf)
+  h = Hiki::History.new(@cgi, @db, @conf)
   h.history_diff
 end
 
-add_body_enter_proc(Proc::new do
+add_body_enter_proc(Proc.new do
   add_plugin_command('history', history_label, {'p' => true})
 end)
 
@@ -93,11 +94,11 @@ module Hiki
     # Subroutine to output proper HTML for Hiki.
     def history_output(s)
       # Imported codes from hiki/command.rb::cmd_view()
-      parser = @conf.parser::new( @conf )
+      parser = @conf.parser.new( @conf )
       tokens = parser.parse( s )
-      formatter = @conf.formatter::new( tokens, @db, @plugin, @conf )
-      @page  = Page::new( @cgi, @conf )
-      data   = Util::get_common_data( @db, @plugin, @conf )
+      formatter = @conf.formatter.new( tokens, @db, @plugin, @conf )
+      @page  = Page.new( @cgi, @conf )
+      data   = Util.get_common_data( @db, @plugin, @conf )
       @plugin.hiki_menu(data, @cmd)
       pg_title = @plugin.page_name(@p)
       data[:title]      = title( "#{pg_title} - #{history_label}")
@@ -127,9 +128,9 @@ module Hiki
       title = title.compact
       title.reverse! unless rev2.nil?
       title = title.join("<=>").escapeHTML
-      
+
       do_link = (link and rev1)
-      
+
       rv = "["
       if do_link
         rev_param = "r=#{rev1[0]}"
@@ -157,42 +158,47 @@ module Hiki
       sources << "\n<br>\n"
       sources << "\n<table border=\"1\">\n"
       if @conf.options['history.hidelog']
-        sources << " <tr><th>#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[2].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr>\n"
+        case history_repos_type
+        when 'cvs'
+          sources << " <tr><th>#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[2].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr>\n"
+        else
+          sources << " <tr><th>#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr>\n"
+        end
       else
-	case history_repos_type
-	when 'cvs'
-		sources << " <tr><th rowspan=\"2\">#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[2].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr><tr><th colspan=\"3\">#{history_th_label[4].escapeHTML}</th></tr>\n"
-	else
-		sources << " <tr><th rowspan=\"2\">#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr><tr><th colspan=\"2\">#{history_th_label[4].escapeHTML}</th></tr>\n"
-	end
+        case history_repos_type
+        when 'cvs'
+          sources << " <tr><th rowspan=\"2\">#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[2].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr><tr><th colspan=\"3\">#{history_th_label[4].escapeHTML}</th></tr>\n"
+        else
+          sources << " <tr><th rowspan=\"2\">#{history_th_label[0].escapeHTML}</th><th>#{history_th_label[1].escapeHTML}</th><th>#{history_th_label[3].escapeHTML}</th></tr><tr><th colspan=\"2\">#{history_th_label[4].escapeHTML}</th></tr>\n"
+        end
       end
       revs.each do |rev,time,changes,log|
         #    time << " GMT"
         op = "[<a href=\"#{@conf.cgi_name}#{cmdstr('plugin', "plugin=history_src;p=#{@p.escape};r=#{rev}")}\">View</a> this version] "
-	if revs.size != 1
-	  op << "[Diff to "
-	  op << "<a href=\"#{@conf.cgi_name}#{cmdstr('plugin', "plugin=history_diff;p=#{@p.escape};r=#{rev}")}\">current</a>" unless prevdiff == 1
-	  op << " | " unless (prevdiff == 1 || prevdiff >= revs.size)
-	  op << "<a href=\"#{@conf.cgi_name}#{cmdstr('plugin', "plugin=history_diff;p=#{@p.escape};r=#{rev};r2=#{revs[prevdiff][0]}")}\">previous</a>" unless prevdiff >= revs.size
-	  op << "]"
-	end
+        if revs.size != 1
+          op << "[Diff to "
+          op << "<a href=\"#{@conf.cgi_name}#{cmdstr('plugin', "plugin=history_diff;p=#{@p.escape};r=#{rev}")}\">current</a>" unless prevdiff == 1
+          op << " | " unless (prevdiff == 1 || prevdiff >= revs.size)
+          op << "<a href=\"#{@conf.cgi_name}#{cmdstr('plugin', "plugin=history_diff;p=#{@p.escape};r=#{rev};r2=#{revs[prevdiff][0]}")}\">previous</a>" unless prevdiff >= revs.size
+          op << "]"
+        end
         if @conf.options['history.hidelog']
-	  case history_repos_type
-	  when 'cvs' 
+          case history_repos_type
+          when 'cvs'
             sources << " <tr><td>#{rev}</td><td>#{time.escapeHTML}</td><td>#{changes.escapeHTML}</td><td align=right>#{op}</td></tr>\n"
-	  else
+          else
             sources << " <tr><td>#{rev}</td><td>#{time.escapeHTML}</td><td align=right>#{op}</td></tr>\n"
-	  end
+          end
         else
           log.gsub!(/=============================================================================/, '')
           log.chomp!
           log = "*** no log message ***" if log.empty?
-	  case history_repos_type
-	  when 'cvs'
+          case history_repos_type
+          when 'cvs'
             sources << " <tr><td rowspan=\"2\">#{rev}</td><td>#{time.escapeHTML}</td><td>#{changes.escapeHTML}</td><td align=right>#{op}</td></tr><tr><td colspan=\"3\">#{log.escapeHTML}</td></tr>\n"
-	  else
+          else
             sources << " <tr><td rowspan=\"2\">#{rev}</td><td>#{time.escapeHTML}</td><td align=right>#{op}</td></tr><tr><td colspan=\"2\">#{log.escapeHTML}</td></tr>\n"
-	  end
+          end
         end
         prevdiff += 1
       end
@@ -230,16 +236,16 @@ module Hiki
       r = @cgi.params['r'][0] || '1'
       r2 = @cgi.params['r2'][0]
       if r2.nil? || r2.to_i == 0
-	new = @db.load(@p)
-	old = @conf.repos.get_revision(@p, r)
+        new = @db.load(@p)
+        old = @conf.repos.get_revision(@p, r)
       else
-	new = @conf.repos.get_revision(@p, r)
-	old = @conf.repos.get_revision(@p, r2)
+        new = @conf.repos.get_revision(@p, r)
+        old = @conf.repos.get_revision(@p, r2)
       end
 
       # parse the result and make revisions array
       revs = @conf.repos.revisions(@p)
-      
+
       prev2_rev, prev_rev, curr_rev, next_rev = recent_revs(revs, r.to_i)
       last_rev = revs[0]
 
