@@ -12,7 +12,7 @@ add_conf_proc( 'default', 'Prfrences de base' ) do
       <p><input name="author_name" value="#{CGI::escapeHTML(@conf.author_name)}" size="40"></p>
       <h3 class="subtitle">Adresse lectronique</h3>
       <p>Entrez votre adresse e-mail.</p>
-      <p><input name="mail" value="#{CGI::escapeHTML(@conf.mail)}" size="40"></p>
+      <p><textarea name="mail" rows="4" cols="50">#{CGI::escapeHTML(@conf.mail.join("\n"))}</textarea></p>
       <h3 class="subtitle">Notification par e-mail.</h3>
       <p>Si cette option est active, un e-mail de notification sera envoy  votre adresse lectronique via le serveur SMTP (dfinit dans hikiconf.rb) lorsqu'une page est modifie.  Aucun e-mail ne sera envoy si cette option est dsactive.</p>
       <p><select name="mail_on_update">
